==========================
AMaaS Utilities for Python
==========================

This is the Asset Management as a Service (AMaaS) Utilities pack
for Python.

What is AMaaS?
--------------
AMaaS is a modular platform for Asset Managers with an open, RESTful API for programmatic access to its functionality.


For more information, please visit: http://www.amaas.com/.

What are the AMaaS Utilities?
-----------------------------
This package contains helper functions for Python which the AMaaS team feels might be useful for people
building Python based applications.

Note this package *does not* contain any business logic - these are purely functions for simple data manipulation
or transformation.  For business logic helpers, see: https://github.com/amaas-fintech/amaas-core-sdk-python

Quick Start
-----------
Install the AMaaS Utils library from PyPI:

.. code-block:: sh

    $ pip install amaasutils

